@@ -44,7 +44,7 @@ namespace Banshee.Gui
     public abstract class GtkBaseClient : Client
     {
         static GtkBaseClient () {
-            Paths.ApplicationName = Application.InternalName;
+            Application.InitializePaths ();
             user_gtkrc = Path.Combine (Paths.ApplicationData, "gtkrc");
         }
 
@@ -150,9 +150,11 @@ namespace Banshee.Gui
             ThreadAssist.ProxyToMainHandler = Banshee.ServiceStack.Application.Invoke;
 
             Gdk.Global.ProgramClass = Application.InternalName;
-#if HAVE_GLIBSHARP_2_12_7
             GLib.Global.ApplicationName = "Banshee";
-#endif
+
+            // TODO: Set this to "video" when we're playing a video. PulseAudio doesn't treat it differently
+            // than "music" for now, but it would be more correct.
+            Environment.SetEnvironmentVariable ("PULSE_PROP_media.role", "music");
 
             if (ApplicationContext.Debugging) {
                 GLib.Log.SetLogHandler ("Gtk", GLib.LogLevelFlags.Critical, GLib.Log.PrintTraceLogFunction);
