@@ -30,6 +30,8 @@
 
 using System;
 using System.Collections.Generic;
+using System.Linq;
+
 using Mono.Unix;
 using Mono.Addins;
 
@@ -48,7 +50,7 @@ namespace Banshee.Dap
     {
         private Dictionary<string, DapSource> sources;
         private List<DeviceCommand> unhandled_device_commands;
-        private List<TypeExtensionNode> supported_dap_types;
+        private List<DapPriorityNode> supported_dap_types;
         private bool initialized;
         private object sync = new object ();
 
@@ -58,12 +60,18 @@ namespace Banshee.Dap
 
         public void DelayedInitialize ()
         {
+            // This group source gives us a seperator for DAPs in the source view.
+            SourceManager.GroupSource dap_group = new SourceManager.GroupSource (Catalog.GetString ("Devices"), 400);
+            ThreadAssist.ProxyToMain (delegate {
+                ServiceManager.SourceManager.AddSource (dap_group);
+            });
+
             lock (sync) {
                 if (initialized || ServiceManager.HardwareManager == null)
                     return;
 
                 sources = new Dictionary<string, DapSource> ();
-                supported_dap_types = new List<TypeExtensionNode> ();
+                supported_dap_types = new List<DapPriorityNode> ();
 
                 AddinManager.AddExtensionNodeHandler ("/Banshee/Dap/DeviceClass", OnExtensionChanged);
 
@@ -72,24 +80,35 @@ namespace Banshee.Dap
                 ServiceManager.HardwareManager.DeviceCommand += OnDeviceCommand;
                 ServiceManager.SourceManager.SourceRemoved += OnSourceRemoved;
                 initialized = true;
+
+                // Now that we've loaded all the enabled DAP providers, load the devices
+                foreach (IDevice device in ServiceManager.HardwareManager.GetAllDevices ()) {
+                    MapDevice (device);
+                }
             }
         }
 
         private void OnExtensionChanged (object o, ExtensionNodeEventArgs args)
         {
             lock (sync) {
-                TypeExtensionNode node = (TypeExtensionNode)args.ExtensionNode;
+                var node = (DapPriorityNode)args.ExtensionNode;
+                if (!node.Type.IsSubclassOf (typeof (DapSource)))
+                    return;
 
                 if (args.Change == ExtensionChange.Add) {
                     Log.DebugFormat ("Dap support extension loaded: {0}", node.Addin.Id);
-                    supported_dap_types.Add (node);
 
-                    // See if any existing devices are handled by this new DAP support
-                    foreach (IDevice device in ServiceManager.HardwareManager.GetAllDevices ()) {
-                        MapDevice (device);
+                    supported_dap_types.Add (node);
+                    supported_dap_types.Sort ((left, right) => right.Priority.CompareTo (left.Priority));
+
+                    if (initialized) {
+                        // See if any existing devices are handled by this new DAP support
+                        foreach (IDevice device in ServiceManager.HardwareManager.GetAllDevices ()) {
+                            MapDevice (device);
+                        }
                     }
                 } else if (args.Change == ExtensionChange.Remove) {
-                    supported_dap_types.Remove (node);
+                    supported_dap_types.Remove ((DapPriorityNode) args.ExtensionNode);
 
                     Queue<DapSource> to_remove = new Queue<DapSource> ();
                     foreach (DapSource source in sources.Values) {
@@ -195,7 +214,8 @@ namespace Banshee.Dap
 
                         source = service.FindDeviceSource (device);
                         if (source != null) {
-                            Log.DebugFormat ("Found DAP support ({0}) for device {1}", source.GetType ().FullName, source.Name);
+                            Log.DebugFormat ("Found DAP support ({0}) for device {1} and Uuid {2}", source.GetType ().FullName,
+                                             source.Name, device.Uuid);
                             service.sources.Add (device.Uuid, source);
                         }
                     } catch (Exception e) {
@@ -205,6 +225,7 @@ namespace Banshee.Dap
 
                 if (source != null) {
                     ThreadAssist.ProxyToMain (delegate {
+
                         ServiceManager.SourceManager.AddSource (source);
                         source.NotifyUser ();
 
